# Portal Components

## Getting Started
#### Dependencies
You need Python 3.7 or later to use **cgemail**.
```
pip install setuptools
pip install wheel
pip install twine
```
#### Installation
Clone this repo to your local machine using:
```
git clone https://github.com/ramirooliveiracg/cgemail.git
```
## Features
- File structure for PyPI packages
- Setup with package informations
- License example